OC.L10N.register(
    "admin_migrate",
    {
    "Export data" : "Flytja út gögn",
    "All system files and user data" : "Allar kerfisskrár og gögn notanda",
    "Only system files" : "Aðeins kerfisskrár",
    "Only user data" : "Aðeins notandagögn",
    "Export" : "Flytja út"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
